@@ -6,7 +6,7 @@ use Encode;
 use Tie::IxHash;
 no warnings 'uninitialized';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 has 'json' => (
     is => 'ro',
@@ -80,11 +80,11 @@ sub Close {
             my $result = $self->reference->{$tmp.'/'.$key}[0];
             if (ref($self->reference->{$self->tmp}[$total - 1]) eq 'HASH') {
                 if ($type == 1) {
-                    push($self->reference->{$self->tmp}, {$key => $result});
+                    push(@{$self->reference->{$self->tmp}}, {$key => $result});
                 }elsif($type == 2) {
                     $self->reference->{$self->tmp}[$total - 1]{$key} = [$result];
                 }elsif($type == 3) {
-                    push($self->reference->{$self->tmp}, {$key => [$result]});
+                    push(@{$self->reference->{$self->tmp}}, {$key => [$result]});
                 }else{
                     $self->reference->{$self->tmp}[$total - 1]{$key} = $result;
                 }
@@ -94,11 +94,11 @@ sub Close {
                     $t = scalar(@{$self->reference->{$self->tmp}[$total - 1]}) || 1;
                 }
                 if ($type == 1) {
-                    push($self->reference->{$self->tmp}[$total - 1], {$key => $result});
+                    push(@{$self->reference->{$self->tmp}[$total - 1]}, {$key => $result});
                 }elsif($type == 2) {
                     $self->reference->{$self->tmp}[$total - 1][$t - 1]{$key} = [$result];
                 }elsif($type == 3) {
-                    push($self->reference->{$self->tmp}[$total - 1], {$key => [$result]});
+                    push(@{$self->reference->{$self->tmp}[$total - 1]}, {$key => [$result]});
                 }else{
                     if ($self->reference->{$self->tmp}[$total - 1][$t - 1]) {
                         $self->reference->{$self->tmp}[$total - 1][$t]{$key} = $result;
@@ -110,11 +110,11 @@ sub Close {
         }else{
             if (ref($self->reference->{$self->tmp}[$total - 1]) eq 'HASH') {
                 if ($type == 1) {
-                    push($self->reference->{$self->tmp}, {$key => $self->reference->{$tmp.'/'.$key}});
+                    push(@{$self->reference->{$self->tmp}}, {$key => $self->reference->{$tmp.'/'.$key}});
                 }elsif($type == 2) {
                     $self->reference->{$self->tmp}[$total - 1]{$key} = [$self->reference->{$tmp.'/'.$key}];
                 }elsif($type == 3) {
-                    push($self->reference->{$self->tmp}, {$key => [$self->reference->{$tmp.'/'.$key}]});
+                    push(@{$self->reference->{$self->tmp}}, {$key => [$self->reference->{$tmp.'/'.$key}]});
                 }else{
                     $self->reference->{$self->tmp}[$total - 1]{$key} = $self->reference->{$tmp.'/'.$key};
                 }
@@ -124,11 +124,11 @@ sub Close {
                     $t = scalar(@{$self->reference->{$self->tmp}[$total - 1]}) || 1;
                 }
                 if ($type == 1) {
-                    push($self->reference->{$self->tmp}[$total - 1], {$key => $self->reference->{$tmp.'/'.$key}});
+                    push(@{$self->reference->{$self->tmp}[$total - 1]}, {$key => $self->reference->{$tmp.'/'.$key}});
                 }elsif($type == 2) {
                     $self->reference->{$self->tmp}[$total - 1][$t - 1]{$key} = [$self->reference->{$tmp.'/'.$key}];
                 }elsif($type == 3) {
-                    push($self->reference->{$self->tmp}[$total - 1], {$key => [$self->reference->{$tmp.'/'.$key}]});
+                    push(@{$self->reference->{$self->tmp}[$total - 1]}, {$key => [$self->reference->{$tmp.'/'.$key}]});
                 }else{
                     $self->reference->{$self->tmp}[$total - 1][$t - 1]{$key} = $self->reference->{$tmp.'/'.$key};
                 }
@@ -140,11 +140,11 @@ sub Close {
             my $result = $self->reference->{$tmp.'/'.$key}[0];
             if (ref($self->json->[$total - 1]) eq 'HASH') {
                 if ($type == 1) {
-                    push($self->json, {$key => $result});
+                    push(@{$self->json}, {$key => $result});
                 }elsif($type == 2) {
                     $self->json->[$total - 1]{$key} = [$result];
                 }elsif($type == 3) {
-                    push($self->json, {$key => [$result]});
+                    push(@{$self->json}, {$key => [$result]});
                 }else{
                     $self->json->[$total - 1]{$key} = $result;
                 }
@@ -154,11 +154,11 @@ sub Close {
                     $t = scalar(@{$self->json->[$total - 1]}) || 1;
                 }
                 if ($type == 1) {
-                    push($self->json->[$total - 1], {$key => $result});
+                    push(@{$self->json->[$total - 1]}, {$key => $result});
                 }elsif($type == 2) {
                     $self->json->[$total - 1][$t - 1]{$key} = [$result];
                 }elsif($type == 3) {
-                    push($self->json->[$total - 1], {$key => [$result]});
+                    push(@{$self->json->[$total - 1]}, {$key => [$result]});
                 }else{
                     $self->json->[$total - 1][$t - 1]{$key} = $result;
                 }
@@ -166,11 +166,11 @@ sub Close {
         }else{
             if (ref($self->json->[$total - 1]) eq 'HASH') {
                 if ($type == 1) {
-                    push($self->json, {$key => $self->reference->{$tmp.'/'.$key}});
+                    push(@{$self->json}, {$key => $self->reference->{$tmp.'/'.$key}});
                 }elsif($type == 2) {
                     $self->json->[$total - 1]{$key} = [$self->reference->{$tmp.'/'.$key}];
                 }elsif($type == 3) {
-                    push($self->json, {$key => [$self->reference->{$tmp.'/'.$key}]});
+                    push(@{$self->json}, {$key => [$self->reference->{$tmp.'/'.$key}]});
                 }else{
                     $self->json->[$total - 1]{$key} = $self->reference->{$tmp.'/'.$key};
                 }
@@ -180,11 +180,11 @@ sub Close {
                     $t = scalar(@{$self->json->[$total - 1]}) || 1;
                 }
                 if ($type == 1) {
-                    push($self->json, {$key => $self->reference->{$tmp.'/'.$key}});
+                    push(@{$self->json}, {$key => $self->reference->{$tmp.'/'.$key}});
                  }elsif($type == 2) {
                     $self->json->[$total - 1]{$key} = [$self->reference->{$tmp.'/'.$key}];
                 }elsif($type == 3) {
-                    push($self->json, {$key => [$self->reference->{$tmp.'/'.$key}]});
+                    push(@{$self->json}, {$key => [$self->reference->{$tmp.'/'.$key}]});
                 }else{
                     $self->json->[$total - 1]{$key} = $self->reference->{$tmp.'/'.$key};
                 }
@@ -310,7 +310,7 @@ WJSON - Write JSON with simplicities
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
